@@ -49,9 +49,29 @@ class Decanter(Daemon):
                 pidfile, stdout=stdout, stderr=stderr)
 
     def install(self, plugins=[]):
+        third_party_plugin_dir = '/'.join([self.config.apppath, 'plugins'])
+        third_party_plugin_module = '.'.join([
+            self.config.apppath.strip(os.path.sep).split(os.path.sep).pop(),
+            'plugins'])
         for plugin in plugins:
             name = ''.join([plugin.capitalize(), 'Plugin'])
-            cls = getattr(lib.plugin, name)
+            cls = getattr(lib.plugin, name, None)
+
+            if not cls and os.path.isdir(third_party_plugin_dir):
+                for plugin_file in os.listdir(third_party_plugin_dir):
+                    if not plugin_file.endswith('.py'):
+                        continue
+                    module = __import__(
+                        '.'.join([
+                            third_party_plugin_module,
+                            os.path.splitext(plugin_file)[0]]),
+                        fromlist=[name])
+                    cls = getattr(module, name, None)
+                    if cls:
+                        break
+
+            if not cls:
+                raise ImportWarning(name + ' is not faund.')
             bottle.install(cls())
 
     def daemonize(self):
@@ -100,7 +120,7 @@ class Decanter(Daemon):
             print("Decanter is not running")
 
 
-def parse_args(filepath=__file__, source=sys.argv):
+def parse_args(filepath=__file__, source=sys.argv, custom_commands=[]):
     """
     This function will parse command line arguments. To display help and exit
     if the argument is invalid. Will return command, hostname, port and config.
@@ -122,7 +142,7 @@ def parse_args(filepath=__file__, source=sys.argv):
                     '-p {port} -c config/devel.py start'.format(
                     **defaults), conflict_handler='resolve')
     parser.add_argument('command', choices=[
-                        'start', 'stop', 'restart', 'status', 'runserver'])
+                        'start', 'stop', 'restart', 'status', 'runserver'] + custom_commands)
     parser.add_argument('-h', '--hostname', default=defaults['hostname'])
     parser.add_argument('-p', '--port', type=int, default=defaults['port'])
     parser.add_argument(
